# pyautd3

[autd3 library](https://github.com/shinolab/autd3) for python3.7+

version: 2.7.0

## Install

```
pip install pyautd3
```

or from this repository

```
pip install git+https://github.com/shinolab/autd3.git#subdirectory=python
```

## Requirements

If you are using Linux/macOS, you may need to install and run pyautd3 as root.

```
sudo pip install pyautd3
sudo python
>>> import pyautd3
```

## Example

see [example](./example)

## LICENSE

See [LICENSE](https://github.com/shinolab/autd3/blob/master/LICENSE).

# Author

Shun Suzuki, 2022
